==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu_ES">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Antolatu</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Bidali atzera</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Hautatu hau</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiatu</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Itsatsi</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editatu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ezabatu</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Ezarpen orokorrak</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Irudi ezarpenak</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Kolorea</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Testu kolorea</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Zabalera</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Zenbaki hazia</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Ofuskazio-faktorea</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Itxi</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Itxi besteak</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Itxi guztiak</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Itxi guztiak ezkerrera</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Itxi guztiak eskuinera</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Gaituta</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desgaituta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Ezarri</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Letra-tamaina</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Lodia</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Etzana</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Azpimarratua</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Irudi efektuak</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Efekturik ez</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Grisen eskala</translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Mugatuta</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Ezarri</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Kolorea:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Biratu irudia</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrarioa</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Balio positiboak erlojuaren orratzen noranzkoan biratzen dira, balio negatiboak erlojuaren orratzen noranzkoan.
90° ez diren biderkatzaileen bidez biratzeak kalitate galera ekar dezake.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontala</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Bertikala</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ados</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Biratu</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Irauli</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Eskalatu irudia</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Mantendu itxura-erlazioa</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Zabalera:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altuera:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ados</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Ehunekoa</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Pegatina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Hautatu</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zenbakia</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testua</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Gezia</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Gezi bikoitza</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lerroa</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Lausotu</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Laukizuzena</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsea</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Zenbaki erakuslea</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Pegatina</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelatu</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Testu erakuslea</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Testu gezia</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Zenbaki gezia</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Bikoiztu</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Handitu (% 1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Txikiagotu (% 1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Berrezarri zooma (% 1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu_ES">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Antolatu</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Bidali atzera</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Hautatu hau</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiatu</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Itsatsi</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editatu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ezabatu</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Ezarpen orokorrak</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Irudi ezarpenak</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Kolorea</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Testu kolorea</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Zabalera</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Zenbaki hazia</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Ofuskazio-faktorea</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Itxi</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Itxi besteak</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Itxi guztiak</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Itxi guztiak ezkerrera</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Itxi guztiak eskuinera</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Gaituta</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desgaituta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">Biratu</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Ezarri</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Bertikala</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Horizontala</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Ezarri</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Utzi</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Letra-tamaina</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Lodia</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Etzana</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Azpimarratua</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Irudi efektuak</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Efekturik ez</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Grisen eskala</translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Mugatuta</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Ezarri</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Kolorea:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Biratu irudia</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrarioa</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Balio positiboak erlojuaren orratzen noranzkoan biratzen dira, balio negatiboak erlojuaren orratzen noranzkoan.
90° ez diren biderkatzaileen bidez biratzeak kalitate galera ekar dezake.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontala</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Bertikala</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ados</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Biratu</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Irauli</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Eskalatu irudia</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Mantendu itxura-erlazioa</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Zabalera:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altuera:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ados</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Utzi</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Ehunekoa</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Pegatina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Hautatu</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Zenbakia</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testua</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Gezia</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Gezi bikoitza</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lerroa</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Lausotu</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Laukizuzena</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsea</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Zenbaki erakuslea</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Pegatina</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelatu</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Testu erakuslea</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Testu gezia</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Zenbaki gezia</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Bikoiztu</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Handitu (% 1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Txikiagotu (% 1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Berrezarri zooma (% 1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
